@@ -6,7 +6,7 @@ import (
 
 	_ "github.com/prestodb/presto-go-client/presto"
 
-	"github.com/operator-framework/operator-metering/pkg/db"
+	"github.com/kube-reporting/metering-operator/pkg/db"
 )
 
 const (
